@@ -48,7 +48,8 @@ class Teacher(abstract.LessonbasedTeacher):
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
-                and self.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG):
+                and self.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG) \
+                and (not self.get_bool('one_chance_only')):
             return Teacher.ERR_PICKY
 
         self.m_is_first_question = self.q_status == const.QSTATUS_NO
@@ -104,12 +105,14 @@ class Teacher(abstract.LessonbasedTeacher):
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
-        if not runtime.has_gnome_canvas():
-            self.practise_box.add(gtk.Label(_(
-"""This exercise doesn't work without GNOME.
-It can pretty easy be converted to use Pixmap instead
-of GnomeCanvas, but I (tca) don't have time to do this
-right now. But I can answer questions if needed.""")))
+        if runtime.has_gnome_canvas() or runtime.use_cairo_widgets:
+            self.m_usable = True
+        else:
+            self.m_usable = False
+        if not self.m_usable:
+            label = gtk.Label(_("This exercise is disabled because some required features are missing from your computer. You should either install PyGTK 2.8.0 or newer, or GnomeCanvas and its python bindings."))
+            label.set_line_wrap(True)
+            self.practise_box.add(label)
             self.practise_box.show_all()
             return
         v = []
@@ -184,6 +187,8 @@ right now. But I can answer questions if needed.""")))
         frame.add(vbox)
         vbox.pack_start(gu.nCheckButton(self.m_exname,
                     "warning_sound", _("Play warning sound")))
+        vbox.pack_start(gu.nCheckButton(self.m_exname, "one_chance_only",
+                  _("Only one chance to get the answer right")))
         self.config_box.pack_start(frame, False)
         self.config_box.show_all()
         ##############
@@ -229,15 +234,22 @@ _("""You have to select some tones practise. Do this on the config page by setti
                     self.flash_and_play_first_tone()
                     return
                 self.g_flashbar.flash(_("Wrong"))
-                self.g_give_up.set_sensitive(True)
-                if self.get_bool("warning_sound"):
-                    if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
+                if self.get_bool('one_chance_only'):
+                    self.m_t.new_question()
+                    if self.get_bool("warning_sound"):
                         self.m_t.spank_me_play_question()
                     else:
-                        self.m_t.spank_me()
-                else:
-                    if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
                         self.m_t.play_question()
+                else:
+                    self.g_give_up.set_sensitive(True)
+                    if self.get_bool("warning_sound"):
+                        if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
+                            self.m_t.spank_me_play_question()
+                        else:
+                            self.m_t.spank_me()
+                    else:
+                        if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
+                            self.m_t.play_question()
         self.set_percentage_label()
     def give_up(self, _o=None):
         if self.m_t.q_status == const.QSTATUS_WRONG:
@@ -250,14 +262,14 @@ _("""You have to select some tones practise. Do this on the config page by setti
     def set_percentage_label(self):
         self.g_percentage.set_text("%.1f %%" % (self.m_t.m_statistics.get()*100))
     def on_start_practise(self):
-        if not runtime.has_gnome_canvas():
+        if not self.m_usable:
             return
         self.g_flashbar.require_size([
             _("Click 'New tone' to begin."),
             _("Correct, but you have already solved this question"),
             _("Wrong, but you have already solved this question"),
         ])
-        if not runtime.has_gnome_canvas():
+        if not self.m_usable:
             return # this exercise don't work without GnomeCanvas
         if 'white_keys_weight' in self.m_t.m_P.header:
             if type(self.m_t.m_P.header.white_keys_weight) == list \
@@ -288,5 +300,5 @@ _("""You have to select some tones practise. Do this on the config page by setti
         self.m_t.q_status = const.QSTATUS_NO
     def on_end_practise(self):
         self.m_t.end_practise()
-        if runtime.has_gnome_canvas():
+        if self.m_usable:
             self.g_repeat.set_sensitive(False)
