@@ -30,29 +30,34 @@ import configureoutput
 
 import optparse
 
-opt_parser = optparse.OptionParser(usage='GNU Solfege %s\nType "man solfege" for more details.' % configureoutput.VERSION_STRING )
+opt_parser = optparse.OptionParser()
 opt_parser.add_option('-v', '--version', action='store_true', dest='version')
 opt_parser.add_option('-w', '--warranty', action='store_true', dest='warranty',
-    help='show warranty and copyright')
+    help=_('Show warranty and copyright.'))
 opt_parser.add_option('--no-splash', action='store_false', dest='no_splash',
+    help=_('Do not show the startup window.'),
     default=False)
 opt_parser.add_option('--verbose-sound-init', action='store_true',
     default=False,
-    dest='verbose_sound_init', help='Display more info about the sound setup')
+    dest='verbose_sound_init',
+    help=_('Display more info about the sound setup.'))
 opt_parser.add_option('--no-sound', action='store_true', dest='no_sound',
     default=False,
-    help='Do not play any sounds. Useful when porting.')
+    help=_('Do not play any sounds. Instead some data is printed to standard output. Use this for debugging and porting.'))
 opt_parser.add_option('--no-random', action='store_true', dest='no_random',
-    help='For debugging only: Select questions from lesson files in sequential order.')
+    help=_('For debugging only: Select questions from lesson files in sequential order.'))
 opt_parser.add_option('--without-gtkhtml', action='store_true', 
     dest='without_gtkhtml',
-    help='Run without gtkhtml2 even if it is installed')
+    help=_('Run without using gtkhtml2 even if it is installed.'))
 opt_parser.add_option('--without-gnome', action='store_true', 
     dest='without_gnome',
-    help='Run without the gnome module even if it is installed')
+    help=_('Run without the gnome module (especially gnomecanvas) even if it is installed.'))
+opt_parser.add_option('--no-cairo-widgets', action='store_true',
+    dest='no_cairo_widgets',
+    help=_("Do not use the cairo version of input widgets, even if we run gtk+ 2.8.0 or newer."))
 opt_parser.add_option('--show-gtk-warnings', action='store_true',
     dest='show_gtk_warnings',
-    help='Show GtkWarnings in the traceback window')
+    help=_('Show GtkWarnings in the traceback window.'))
 
 
 options, args = opt_parser.parse_args()
